﻿--[[
    Copyright Daniel D. Neilson, 2006

    This file is part of DKPmonInit.

    DKPmonInit is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    DKPmonInit is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with DKPmonInit; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
]]

local options = {
    type = 'group',
    args = {
        initdb = {
            type = 'execute',
            name = 'initdb',
            desc = 'Wipe & initialize the DKPmon database with the contents provided in the .lua files.',
            func = function() DKPmonInit:VerifyInitDB() end
        },
        autoimport = {
            type = 'toggle',
            name = "auto",
            desc = "Toggle auto-loading and importing of database",
            get = "GetAutoInit",
            set = "ToggleAutoInit",
            map = { [false] = "|cffff0000Off|r", [true] = "|cff00ff00On|r" },
        },
    }
}

DKPmonInit = AceLibrary("AceAddon-2.0"):new("AceConsole-2.0", "AceDB-2.0", "AceDebug-2.0")
-- Set the console commands
DKPmonInit:RegisterChatCommand({"/dkpinit", "/dkpmoninit"}, options)

DKPmonInit:RegisterDB("DKPmonInitDB")
DKPmonInit:RegisterDefaults('profile', {
    autoImport = false,
    lastImport = 0,
    } )



function DKPmonInit:OnInitialize()
    -- Called when the addon is loaded
    StaticPopupDialogs["DKPMONINIT_CONFIRM_INITDB"] = {
        text = "Are you sure you wish to initialize your database? This will wipe everything currently in the database.",
        button1 = "Yes",
        button2 = "No",
        OnAccept = function()
            DKPmonInit:InitDB()
        end,
        OnCancel = function() end,
        sound = "levelup2",
        timeout = 10,
        whiledead = 1,
        hideOnEscape = 1
    }
end

function DKPmonInit:OnEnable()
    self:Debug("Enabled")
    if DKPmonInit.db.profile.autoImport then
    	if (DKP_fileid > DKPmonInit.db.profile.lastImport) then
    		DKPmonInit:InitDB()
			-- update the timestamp of our last Import
			self.db.profile.lastImport = DKP_fileid
    	end
    end
end

function DKPmonInit:OnDisable()
    -- Called when the addon is disabled.
    self:Debug("Disabled")
end

function DKPmonInit:VerifyInitDB()
    if (DKPmon.db.realm.dbversion < 1.1) or (DKPmon.db.realm.dbversion > 1.2) then
        self:Print("ERROR: Incompatible version of DKPmon installed. Aborting import")
        return
    end
    StaticPopup_Show("DKPMONINIT_CONFIRM_INITDB")
end

function DKPmonInit:InitDB()
    -- Okay, we have the go-ahead.
    -- 1) Wipe the current database
    DKPmon:TableDelete(DKPmon.db.realm.points)
    DKPmon.db.realm.points = {}
    -- 2) Wipe the bidderClasses table
    DKPmon:TableDelete(DKPmon.bidderClasses)
    DKPmon.bidderClasses = {}
    -- 3) start parsing each string in self.csv for import into the database
    local str
    for _,str in pairs(self.csv) do
        local _,_,name = string.find(str, "(%a+):")
        local _,_,class = string.find(str, ":(%a+):")
        name = string.upper(string.sub(name, 1, 1))..string.lower(string.sub(name, 2))
        class = string.upper(class)
        self:Debug(string.format("Name = %s, class = %s", name, class))
        -- Ensure that the class name is valid.
        if Bidder.classInfo.classToNum[class] == nil then   
            -- invalid classname
            self:Print(string.format("ERROR: %s is an invalid classname for %s. Skipping.", class, name))
        else
            DKPmon.bidderClasses[name] = class
            local pool, pnts = 0, 0
            for pnts in string.gmatch(str, ":([-]?[%d]*%.?[%d]+)") do
                pnts = tonumber(pnts)
                if pnts == nil then
                    self:Print(string.format("ERROR: %s has an invalid number for pool %d's value.", name, pool))
                else
                    self:Debug(string.format(" -- Pool %d = %g", pool, pnts))
                    if not (pnts < 0) then
                        DKPmon:AwardPoints(name, pool, pnts)
                    else
                        DKPmon:SpendPoints(name, pool, -pnts)
                    end
                end
                pool = pool + 1
            end
        end
    end

    self:Print("Imported new DKP data");
end

function DKPmonInit:GetAutoInit()
    if (DKPmonInit.db.profile.autoImport == nil) then
        return false
    else
        return DKPmonInit.db.profile.autoImport
    end
end

function DKPmonInit:ToggleAutoInit(newState)
    DKPmonInit.db.profile.autoImport = newState
end

